# Earth - Topography grid at 10 arc-minute resolution

Global 10 arc-minute resolution grids of topography (ETOPO1 ice-surface) referenced
to mean sea-level.

![Global map of topographic height.](preview.jpg)

| | Summary |
|--:|:--|
| File | `earth-topography-10arcmin.nc` |
| Size | 2.7 Mb |
| Version | [v1](https://github.com/fatiando-data/earth-topography-10arcmin/releases/latest) |
| DOI | https://doi.org/10.5281/zenodo.5882203 |
| License | [CC-BY](https://creativecommons.org/licenses/by/4.0/) |
| MD5 | `md5:c43b61322e03669c4313ba3d9a58028d` |
| SHA256 | `sha256:e45628a3f559ec600a4003587a2b575402d22986651ee48806930aa909af4cf6` |
| Source | [ETOPO1](https://doi.org/10.7289/V5C8276M) (grid generated by the [ICGEM calculation service](http://icgem.gfz-potsdam.de/home)) |
| Original license | [public domain](https://ngdc.noaa.gov/mgg/global/dem_faq.html#sec-2.4) |
| Processing code | [`prepare.ipynb`](https://nbviewer.org/github/fatiando-data/earth-topography-10arcmin/blob/main/prepare.ipynb) |

## Changes made

> These are the changes made to the original dataset.

* Convert the grid from the ASCII format of ICGEM to CF-compliant netCDF.
* Add relevant metadata, including names, units, datum, etc.
* Fix grid coordinates to be generated by `numpy.linspace` instead
  `numpy.arange` (or the equivalent used by ICGEM internally) to guarantee
  equal spacing to a higher accuracy.
* Export to compressed netCDF.

## About this repository

This is a place to format and prepare the original dataset for use in our
tutorials and documentation.

We include the source code that prepares the datasets for redistribution by
filtering, standardizing, converting coordinates, compressing, etc.
The goal is to make loading the data as easy as possible (e.g., a single call
to `pandas.read_csv` or `xarray.load_dataset`).
Whenever possible, the code also downloads the original data (otherwise the
original data are included in this repository).

> 💡 **Tip:** The easiest way to download this dataset is using
> [Pooch](https://www.fatiando.org/pooch), particularly to download straight
> from the DOI of a release.

## Contributing

See our [Contributing Guidelines][contrib] for information on proposing new
datasets and making changes to this repository.

## License

All Python source code is made available under the BSD 3-clause license. You
can freely use and modify the code, without warranty, so long as you provide
attribution to the authors.

Unless otherwise specified, all data files and figures created by the code are
available under the Creative Commons Attribution 4.0 License (CC-BY).

See [`LICENSE.txt`](LICENSE.txt) for the full text of each license.

The license for the original data is specified in this `README.md` file.


[contrib]: https://github.com/fatiando-data/.github/blob/main/CONTRIBUTING.md
